#!/bin/bash
#
# Script Name:
# gv4l-convert.sh
#
# Version:
# 0.1
#
# Description:
# This script converts the old configuration Gv4l files (versions prior 2.0.0)
# to the format compatible and used by Gv4l 2.0.0+
#
# Author:
# Todor T. Zviskov (aka Warder) - http://warder.ath.cx:81/
#
# License:
# This script is released under the terms of of the GPL v2. If you don't have a
# copy of the license, it can be obtained at http://www.gnu.org/licenses/gpl.txt
#

oldconf="$HOME/.gv4l";
newconf="$HOME/.gv4l2/config"


gv4lconv()
{
	if [ -f "$newconf" ]; then
		echo -e "The configuration file \"$newconf\" already exists!"
		echo -ne "Would you like to overwrite it? [y/N]: N\b"
		read ans
		if [ "$ans" = "Y" ]; then
			echo -e "\nOverwriting existing file \"$newconf\"."
		elif [ "$ans" = "y" ]; then
			echo -e "\nOverwriting existing file \"$newconf\"."
		else
			echo -e "\nConvertion aborted. Rename \"$newconf\" and run this script again."
			exit 1;
		fi;
	fi;
	echo -e "[Default=Gv4l]\n" > $newconf || exit 1;
	echo "VideoDev=`cat $oldconf|head -n 1|tail -n 1`" >> $newconf
	echo "AudioDev=`cat $oldconf|head -n 2|tail -n 1`" >> $newconf
	echo "PicSize=`cat $oldconf|head -n 3|tail -n 1`" >> $newconf
	echo "FPS=`cat $oldconf|head -n 4|tail -n 1`" >> $newconf
	echo "Codec=`cat $oldconf|head -n 5|tail -n 1`" >> $newconf
	echo "VBitrate=`cat $oldconf|head -n 6|tail -n 1`" >> $newconf
	echo "ABitrate=`cat $oldconf|head -n 7|tail -n 1`" >> $newconf
	echo "AGain=`cat $oldconf|head -n 8|tail -n 1`" >> $newconf
	echo "Source=`cat $oldconf|head -n 9|tail -n 1|cut -d "," -f1`" >> $newconf
	echo "Channel=`cat $oldconf|head -n 9|tail -n 1|cut -d "," -f2`" >> $newconf
	echo "File=`cat $oldconf|head -n 10|tail -n 1`" >> $newconf
	echo "Preview=`cat $oldconf|head -n 11|tail -n 1`" >> $newconf
	echo "Player=`cat $oldconf|head -n 12|tail -n 1`" >> $newconf
	if [ `cat $oldconf|head -n 13|tail -n 1` -gt 0 ]; then
		echo "DeInter=1" >> $newconf
	else
		echo "DeInter=0" >> $newconf
	fi;
	echo "Duration=`cat $oldconf|head -n 14|tail -n 1`" >> $newconf
	echo -e "\n[End Gv4l]\n" >> $newconf
	echo -e "\033[00;32m Successfully converted \"$oldconf\" to \"$newconf\".\033[00m"
}



if [ "$1" ]; then
	echo
	if [ ! -f "$1" ]; then
		echo -e "\033[01;31mThe supplied argument is not a valid file!\033[00m"
		echo
		echo
		echo -e "\033[01mThis script doesn't require any aruments.\033[00m"
		echo "To convert all confiuration files created by Gv4l versions prior 2.0.0 run:"
		echo -e "	\033[00;32m /bin/bash gv4l-convert.sh\033[00m"
		echo
		echo "To convert a custom file you created for Gv4l (prior v2.0.0) run:"
		echo -e "	\033[00;32m /bin/bash gv4l-convert.sh $HOME/my_custom_gv4l_config\033[00m"
		exit 1;
	else
		oldconf="$1"
		newconf="$1-gv4l2"
		gv4lconv
	fi;
else
	mkdir $HOME/.gv4l2/ >/dev/null 2>&1
	mkdir $HOME/.gv4l2/cron >/dev/null 2>&1
	mkdir $HOME/.gv4l2/tmp >/dev/null 2>&1
	echo -e "\033[40;01;33mPlease wait, the convertion process WILL take a while...\033[00m\n"
	gv4lconv
	count=0
	while [ "$count" -ne "10000" ]
		do
			if [ "$count" -eq 0 ]
			then
				if [ -f "$HOME/.gv4l-schedule" ]
				then
					oldconf="$HOME/.gv4l-schedule"
					newconf="$HOME/.gv4l2/cron/schedule"
					gv4lconv
					echo -e "\033[01;31mPlease update your crontab to point to the new file!\033[00m"
				fi;
			elif [ -f "$HOME/.gv4l-schedule-$count" ]; then
				oldconf="$HOME/.gv4l-schedule-$count"
				newconf="$HOME/.gv4l2/cron/schedule-$count"
				gv4lconv
				echo -e "\033[01;31mPlease update your crontab to point to the new file!\033[00m"
			fi;
			count=`expr $count + 1`;
		done
		
fi;
echo -e "\nDone."
echo "Press 'ENTER' to continue"
read
